Author: stefan2
Date: Sun Jan 11 02:37:11 2015
New Revision: 1650859
URL: http://svn.apache.org/r1650859
Log:
Continue migrating FSX to the two-pool paradigm. Many single-pool functions
don't allocate a return value, i.e. their pools can immediately be renamed
to SCRATCH_POOL. Do this for string_table.* .
* subversion/libsvn_fs_x/string_table.h
(svn_fs_x__write_string_table): POOL is actually a SCRATCH_POOL.
* subversion/libsvn_fs_x/string_table.c
(svn_fs_x__write_string_table): Same.
Modified:
subversion/trunk/subversion/libsvn_fs_x/string_table.c
subversion/trunk/subversion/libsvn_fs_x/string_table.h
Modified: subversion/trunk/subversion/libsvn_fs_x/string_table.c
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/string_table.c?rev=1650859&r1=1650858&r2=1650859&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/string_table.c (original)
+++ subversion/trunk/subversion/libsvn_fs_x/string_table.c Sun Jan 11 02:37:11
2015
@@ -585,11 +585,11 @@ svn_fs_x__string_table_get(const string_
svn_error_t *
svn_fs_x__write_string_table(svn_stream_t *stream,
const string_table_t *table,
- apr_pool_t *pool)
+ apr_pool_t *scratch_pool)
{
apr_size_t i, k;
- svn_packed__data_root_t *root = svn_packed__data_create_root(pool);
+ svn_packed__data_root_t *root = svn_packed__data_create_root(scratch_pool);
svn_packed__int_stream_t *table_sizes
= svn_packed__create_int_stream(root, FALSE, FALSE);
@@ -646,7 +646,7 @@ svn_fs_x__write_string_table(svn_stream_
/* write to target stream */
- SVN_ERR(svn_packed__data_write(stream, root, pool));
+ SVN_ERR(svn_packed__data_write(stream, root, scratch_pool));
return SVN_NO_ERROR;
}
Modified: subversion/trunk/subversion/libsvn_fs_x/string_table.h
URL:
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_fs_x/string_table.h?rev=1650859&r1=1650858&r2=1650859&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_fs_x/string_table.h (original)
+++ subversion/trunk/subversion/libsvn_fs_x/string_table.h Sun Jan 11 02:37:11
2015
@@ -86,12 +86,12 @@ svn_fs_x__string_table_get(const string_
apr_pool_t *pool);
/* Write a serialized representation of the string table TABLE to STREAM.
* Use POOL for temporary allocations.
*/
svn_error_t *
svn_fs_x__write_string_table(svn_stream_t *stream,
const string_table_t *table,
- apr_pool_t *pool);
+ apr_pool_t *scratch_pool);
/* Read the serialized string table representation from STREAM and return
* the resulting runtime representation in *TABLE_P. Allocate it in
@@ -86,12 +86,12 @@ svn_fs_x__string_table_get(const string_
apr_pool_t *pool);
/* Write a serialized representation of the string table TABLE to STREAM.
- * Use POOL for temporary allocations.
+ * Use SCRATCH_POOL for temporary allocations.
*/
svn_error_t *